PinCodeProvider class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
fetchData({GetDeviceDetailsMethod getDetails = sdk.DevicesRepository.getDeviceDetails})
→ Future<void>
-
inherited
-
getPinCodeTrait()
→ PinCodeTrait?
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
performAction<T>(T desiredState, Function getState, Function action, {GetDeviceDetailsMethod getDetails = sdk.DevicesRepository.getDeviceDetails})
→ Future<void>
-
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
sendCreatePinCode(String pinCode, String pinCodeName, {GetDeviceDetailsMethod getDetails = DevicesRepository.getDeviceDetails, SendCreatePinCodeMethod sendCreatePinCodeMethod = PinCodeRepository.sendCreatePinCodeAction})
→ Future<void>
-
Run the "makeCreatePinCodeActionRequest" mutation on this device
-
sendDeletePinCode(String pinCode, String pinCodeName, {GetDeviceDetailsMethod getDetails = DevicesRepository.getDeviceDetails, SendDeletePinCodeMethod sendDeletePinCodeMethod = PinCodeRepository.sendDeletePinCodeAction})
→ Future<void>
-
Run the "makeDeletePinCodeActionRequest" mutation on this device
-
sendUpdatePinCode(String pinCode, String pinCodeName, {GetDeviceDetailsMethod getDetails = DevicesRepository.getDeviceDetails, SendUpdatePinCodeMethod sendUpdatePinCodeMethod = PinCodeRepository.sendUpdatePinCodeAction})
→ Future<void>
-
Run the "makeUpdatePinCodeActionRequest" mutation on this device
-
setErrorState(String errorMsg)
→ void
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
trait<T extends Trait>()
→ Trait?
-
inherited